# Revision 3010
Index: SConstruct
===================================================================
Index: NEWS
===================================================================
--- NEWS	(.../tags/lighttpd-1.4.36)
+++ NEWS	(.../branches/lighttpd-1.4.x)
@@ -3,7 +3,13 @@
 NEWS
 ====
 
-- 1.4.36
+- 1.4.37
+  * [mod_proxy] remove debug log line from error log (fixes #2659)
+  * [mod_dirlisting] fix dir-listing.set-footer not showing
+  * fix out-of-filedescriptors when uploading "large" files (fixes #2660, thx rmilecki)
+  * increase upload temporary chunk file size from 1MB to 16MB
+
+- 1.4.36 - 2015-07-26
   * use keep-alive timeout while waiting for HTTP headers; use always the read timeout while waiting for the HTTP body
   * fix bad shift in conditional netmask ".../0" handling
   * add more mime types and a script to generate mime.conf (fixes #2579)
Index: CMakeLists.txt
===================================================================
Index: src/mod_proxy.c
===================================================================
--- src/mod_proxy.c	(.../tags/lighttpd-1.4.36)
+++ src/mod_proxy.c	(.../branches/lighttpd-1.4.x)
@@ -940,7 +940,6 @@
 		case 1:
 			/* we are done */
 			proxy_connection_close(srv, hctx);
-			log_error_write(srv, __FILE__, __LINE__, "s", "proxy request finished");
 
 			joblist_append(srv, con);
 			return HANDLER_FINISHED;
Index: src/chunk.c
===================================================================
--- src/chunk.c	(.../tags/lighttpd-1.4.36)
+++ src/chunk.c	(.../branches/lighttpd-1.4.x)
@@ -417,15 +417,16 @@
 }
 
 static int chunkqueue_append_to_tempfile(server *srv, chunkqueue *dest, const char *mem, size_t len) {
+	/* copy everything to max MAX_TEMPFILE_SIZE sized tempfiles */
+	static const off_t MAX_TEMPFILE_SIZE = 16 * 1024 * 1024; /* 16MB */
 	chunk *dst_c = NULL;
 	ssize_t written;
-	/* copy everything to max 1Mb sized tempfiles */
 
 	/*
 	 * if the last chunk is
-	 * - smaller than 1Mb (size < 1Mb)
+	 * - smaller than MAX_TEMPFILE_SIZE
 	 * - not read yet (offset == 0)
-	 * -> append to it
+	 * -> append to it (so it might actually become larger than MAX_TEMPFILE_SIZE)
 	 * otherwise
 	 * -> create a new chunk
 	 *
@@ -432,7 +433,7 @@
 	 * */
 
 	if (NULL != dest->last
-		&& FILE_CHUNK != dest->last->type
+		&& FILE_CHUNK == dest->last->type
 		&& dest->last->file.is_temp
 		&& -1 != dest->last->file.fd
 		&& 0 == dest->last->offset) {
@@ -439,7 +440,7 @@
 		/* ok, take the last chunk for our job */
 		dst_c = dest->last;
 
-		if (dest->last->file.length >= 1 * 1024 * 1024) {
+		if (dest->last->file.length >= MAX_TEMPFILE_SIZE) {
 			/* the chunk is too large now, close it */
 			if (-1 != dst_c->file.fd) {
 				close(dst_c->file.fd);
Index: src/mod_dirlisting.c
===================================================================
--- src/mod_dirlisting.c	(.../tags/lighttpd-1.4.36)
+++ src/mod_dirlisting.c	(.../branches/lighttpd-1.4.x)
@@ -614,7 +614,7 @@
 			"<div class=\"foot\">"
 		));
 
-		if (buffer_string_is_empty(p->conf.set_footer)) {
+		if (!buffer_string_is_empty(p->conf.set_footer)) {
 			buffer_append_string_buffer(out, p->conf.set_footer);
 		} else if (buffer_is_empty(con->conf.server_tag)) {
 			buffer_append_string_len(out, CONST_STR_LEN(PACKAGE_DESC));
Index: configure.ac
===================================================================
